@@ -17,6 +17,7 @@ import (
 	"github.com/charmbracelet/glamour"
 	"github.com/koki-develop/gat/internal/formatters"
 	"github.com/koki-develop/gat/internal/lexers"
+	"github.com/koki-develop/gat/internal/masker"
 	"github.com/koki-develop/gat/internal/prettier"
 	"github.com/koki-develop/gat/internal/styles"
 	"github.com/mattn/go-sixel"
@@ -76,6 +77,7 @@ func New(cfg *Config) (*Gat, error) {
 
 type printOption struct {
 	Pretty   bool
+	Mask     bool
 	Filename string
 }
 
@@ -93,6 +95,12 @@ func WithFilename(name string) PrintOption {
 	}
 }
 
+func WithMask(m bool) PrintOption {
+	return func(o *printOption) {
+		o.Mask = m
+	}
+}
+
 func (g *Gat) Print(w io.Writer, r io.Reader, opts ...PrintOption) error {
 	// parse options
 	opt := &printOption{}
@@ -187,6 +195,11 @@ func (g *Gat) Print(w io.Writer, r io.Reader, opts ...PrintOption) error {
 		}
 	}
 
+	// mask sensitive information
+	if opt.Mask {
+		src = masker.Mask(src)
+	}
+
 	// print
 	it, err := lexer.Tokenise(nil, src)
 	if err != nil {
